@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +26,8 @@ Web Views
 
 
 def includeme(config):
+
+    # native view supplements
     config.include('tailbone_corepos.views.customers')
     config.include('tailbone_corepos.views.departments')
     config.include('tailbone_corepos.views.members')
@@ -34,3 +36,6 @@ def includeme(config):
     config.include('tailbone_corepos.views.stores')
     config.include('tailbone_corepos.views.subdepartments')
     config.include('tailbone_corepos.views.vendors')
+
+    # CORE-POS tables
+    config.include('tailbone_corepos.views.corepos')
